package jp.co.intra_mart.cookbook.im_cookbook_113639.oauth.client.service.processor.impl;

import jp.co.intra_mart.foundation.oauth.client.model.OAuthConnectionInfo;
import jp.co.intra_mart.system.oauth.client.service.AuthzCodeRequest;

/**
 * Google用認可コードリクエストです。<br>
 * 認可コードを取得するため、認可サーバにリクエストする情報を保持するオブジェクトです。<br>
 * <br>
 * {@link AuthzCodeRequest} の情報に加えて以下のパラメータを追加します。
 * <table border="1">
 * <tr>
 * <th>パラメータ名=パラメータ値</th>
 * <th>説明</th>
 * </tr>
 * <tr>
 * <td>access_type=offline</td>
 * <td>refresh_token を取得するために必要</td>
 * </tr>
 * <tr>
 * <td>approval_prompt=force</td>
 * <td>必ず認証を強制します</td>
 * </tr>
 * </table>
 */
public class GoogleAuthzCodeRequest extends AuthzCodeRequest {

    public GoogleAuthzCodeRequest(final String providerId, final OAuthConnectionInfo connectionInfo) {
        super(providerId, connectionInfo);

        addParameter(GoogleConstants.PARAM_NAME_4_ACCESS_TYPE, "offline");
        addParameter(GoogleConstants.PARAM_NAME_4_APPROVAL_PROMPT, "force");
    }

}
