package jp.co.intra_mart.cookbook.im_cookbook_113639.oauth.client.service.processor.impl;

import java.util.ServiceLoader;

import jp.co.intra_mart.system.oauth.client.service.processor.OAuthAuthzCodeRequestProcessor;
import jp.co.intra_mart.system.oauth.client.service.processor.OAuthRefreshAccessTokenRequestProcessor;
import jp.co.intra_mart.system.oauth.client.service.processor.impl.StandardOAuthRequestProcessorFactory;

/**
 * Google向けのOAuthRequestProcessorFactoryです。<br />
 * {@link ServiceLoader}により読みこまれます、以下のファイルに設定が行われています。<br />
 * src/main/resources/META-INF/services/jp.co.intra_mart.system.oauth.client.service.processor.OAuthRequestProcessorFactory
 */
public class GoogleOAuthRequestProcessorFactory extends StandardOAuthRequestProcessorFactory {

    private final OAuthAuthzCodeRequestProcessor authzCodeProcessor;

    private final OAuthRefreshAccessTokenRequestProcessor refreshTokneProcessor;

    public GoogleOAuthRequestProcessorFactory() {
        authzCodeProcessor = new GoogleAuthzCodeRequestProcessor();

        // Googleの場合、アクセストークン更新時の成功レスポンスには refresh_token が含まれない（2016年6月現在）
        refreshTokneProcessor = new RefreshAccessTokenRequestProcessorWithoutRefreshTokenOnSuccessResponse(GoogleConstants.PROVIDER_TYPE);
    }

    @Override
    public OAuthAuthzCodeRequestProcessor getAuthzCodeRequestProcessor() {
        return authzCodeProcessor;
    }

    @Override
    public String getProviderType() {
        return GoogleConstants.PROVIDER_TYPE;
    }

    @Override
    public OAuthRefreshAccessTokenRequestProcessor getRefreshAccessTokenRequestProcessor() {
        return refreshTokneProcessor;
    }

}
